rekha.plots.BoxPlot
===================

.. currentmodule:: rekha.plots

.. autoclass:: BoxPlot

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~BoxPlot.add_annotation
      ~BoxPlot.get_axes
      ~BoxPlot.save
      ~BoxPlot.save_all_formats
      ~BoxPlot.show
      ~BoxPlot.show_legend
      ~BoxPlot.update_layout
   
   

   
   
   